//// [parserGreaterThanTokenAmbiguity15.ts]
1 
// before
>>= // after
2;

//// [parserGreaterThanTokenAmbiguity15.js]
1
    >>=
        2;
